import { _decorator, assetManager, isValid, Sprite, SpriteFrame } from "cc";
import { EDITOR } from "cc/env";
const { ccclass, property, executeInEditMode, requireComponent } = _decorator;

/**
 * 多语言精灵
 */
@ccclass("I18nSprite")
@executeInEditMode
@requireComponent(Sprite)
export class I18nSprite extends Component {
    @property
    private _spfName: string = "";
    @property
    public get spfName() {
        return this._spfName;
    }
    public set spfName(spfName: string) {
        this._spfName = spfName;
        this.updateSpf();
    }

    private _sprite: Sprite = null;

    protected onLoad(): void {
        this._sprite = this.getComponent(Sprite);
    }

    onEnable() {
        this.updateSpf();
    }

    onDisable() {
        if (EDITOR) this._sprite.spriteFrame.destroy(); // 编辑器模式下，需要手动销毁
    }

    updateSpf() {
        if (!isValid(this._sprite)) return;

        if (this._spfName == "") {
            this._sprite.spriteFrame = null;
            return;
        }

        if (EDITOR) {
            // todo 改成你自己的
            const imgPath = `db://assets/i18n/zh/${this._spfName}.png`;
            // @ts-ignore Editor在编辑器下可以访问，报红不用管
            Editor.Message.request("asset-db", "query-uuid", imgPath).then((uuid: string) => {
                assetManager.loadAny({ uuid }, (err, data) => {
                    if (err) return;
                    this._sprite.spriteFrame = SpriteFrame.createWithImage(data);
                });
            });
        } else {
            // todo 正常的动态加载资源逻辑
        }
    }
}
